@@ -18,9 +18,10 @@ use derive_more::{Deref, DerefMut, Display, From, Index, IndexMut, Into};
 use hyper::Body;
 use serde::{Deserialize, Serialize};
 use smartstring::alias::String as SmartString;
-use std::convert::Infallible;
 use std::{
     borrow::{Borrow, Cow},
+    convert::Infallible,
+    fmt::{self, Error as FmtError, Write as FmtWrite},
     iter::FromIterator,
     path::Path,
     str::FromStr,
@@ -94,6 +95,12 @@ impl StackString {
             Cow::Owned(s) => s.into(),
         }
     }
+
+    pub fn from_display(buf: impl fmt::Display) -> Result<Self, FmtError> {
+        let mut s = Self::new();
+        write!(s, "{}", buf)?;
+        Ok(s)
+    }
 }
 
 impl From<StackString> for String {
@@ -102,6 +109,12 @@ impl From<StackString> for String {
     }
 }
 
+impl From<&StackString> for String {
+    fn from(item: &StackString) -> Self {
+        item.as_str().into()
+    }
+}
+
 impl From<&StackString> for StackString {
     fn from(item: &StackString) -> Self {
         item.clone()
@@ -297,7 +310,10 @@ impl From<StackString> for Body {
 
 #[cfg(feature = "sqlx_types")]
 impl sqlx_core::encode::Encode<'_, sqlx_core::postgres::Postgres> for StackString {
-    fn encode_by_ref(&self, buf: &mut sqlx_core::postgres::PgArgumentBuffer) -> sqlx_core::encode::IsNull {
+    fn encode_by_ref(
+        &self,
+        buf: &mut sqlx_core::postgres::PgArgumentBuffer,
+    ) -> sqlx_core::encode::IsNull {
         <&str as sqlx_core::encode::Encode<sqlx_core::postgres::Postgres>>::encode(&**self, buf)
     }
 }
@@ -315,8 +331,11 @@ impl sqlx_core::types::Type<sqlx_core::postgres::Postgres> for StackString {
 
 #[cfg(feature = "sqlx_types")]
 impl sqlx_core::decode::Decode<'_, sqlx_core::postgres::Postgres> for StackString {
-    fn decode(value: sqlx_core::postgres::PgValueRef<'_>) -> Result<Self, sqlx_core::error::BoxDynError> {
-        <String as sqlx_core::decode::Decode<'_, sqlx_core::postgres::Postgres>>::decode(value).map(|s| s.into())
+    fn decode(
+        value: sqlx_core::postgres::PgValueRef<'_>,
+    ) -> Result<Self, sqlx_core::error::BoxDynError> {
+        <String as sqlx_core::decode::Decode<'_, sqlx_core::postgres::Postgres>>::decode(value)
+            .map(|s| s.into())
     }
 }
 
@@ -328,7 +347,7 @@ mod tests {
 
     #[test]
     fn test_smartstring_validate() {
-       smartstring::validate();
+        smartstring::validate();
     }
 
     #[test]
